"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_1 = __importDefault(require("@searchkit/sdk"));
const index_1 = __importDefault(require("../index"));
const mockSearchkitResponse = [
    {
        identifier: "results",
        suggestions: ["sweaters", "sweatpants"]
    },
    {
        identifier: "hits-suggestions",
        hits: [
            {
                id: "test",
                fields: {
                    title: "hello",
                    description: "test"
                },
                highlight: {
                    title: "hello"
                },
                rawHit: {
                    _id: "test"
                }
            }
        ]
    }
];
jest.mock("@searchkit/sdk", () => {
    const originalModule = jest.requireActual("@searchkit/sdk");
    return Object.assign(Object.assign({ __esModule: true }, originalModule), { default: jest.fn((config) => {
            const sk = originalModule.default(config);
            sk.executeSuggestions = jest.fn(() => mockSearchkitResponse);
            return sk;
        }) });
});
describe("Autocomplete results", () => {
    it("success", () => __awaiter(void 0, void 0, void 0, function* () {
        const state = {
            searchTerm: "test"
        };
        const queryConfig = {
            results: {
                resultsPerPage: 5,
                search_fields: {
                    title: {
                        weight: 2
                    }
                },
                result_fields: {
                    title: {
                        snippet: {
                            size: 100,
                            fallback: true
                        }
                    },
                    nps_link: {
                        raw: {}
                    }
                }
            },
            suggestions: {
                types: {
                    results: {
                        fields: ["title"]
                    }
                }
            }
        };
        const results = yield (0, index_1.default)({
            state,
            queryConfig,
            host: "http://localhost:9200",
            index: "test",
            connectionOptions: {
                apiKey: "test"
            }
        });
        const searchkitRequestInstance = sdk_1.default.mock.results[0]
            .value;
        expect(searchkitRequestInstance.executeSuggestions).toBeCalledWith("test");
        expect(results).toMatchInlineSnapshot(`
      Object {
        "autocompletedResults": Array [
          Object {
            "_meta": Object {
              "id": "test",
            },
            "description": Object {
              "raw": "test",
            },
            "id": Object {
              "raw": "test",
            },
            "title": Object {
              "raw": "hello",
              "snippet": "hello",
            },
          },
        ],
        "autocompletedSuggestions": Object {
          "results": Array [
            Object {
              "suggestion": "sweaters",
            },
            Object {
              "suggestion": "sweatpants",
            },
          ],
        },
      }
    `);
    }));
});
